==> sagemaker-0.9.0-sources.jar: software/amazon/awscdk/services/sagemaker/cloudformation/EndpointResourceProps.java <==
package software.amazon.awscdk.services.sagemaker.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:55:15.532Z")
public interface EndpointResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::SageMaker::Endpoint.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
     */
    java.lang.Object getEndpointConfigName();
    /**
     * ``AWS::SageMaker::Endpoint.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
     */
    void setEndpointConfigName(final java.lang.String value);
    /**
     * ``AWS::SageMaker::Endpoint.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
     */
    void setEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::Endpoint.EndpointName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
     */
    java.lang.Object getEndpointName();
    /**
     * ``AWS::SageMaker::Endpoint.EndpointName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
     */
    void setEndpointName(final java.lang.String value);
    /**
     * ``AWS::SageMaker::Endpoint.EndpointName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
     */
    void setEndpointName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::Endpoint.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::SageMaker::Endpoint.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
     */
    void setTags(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::Endpoint.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link EndpointResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link EndpointResourceProps}
     */
    final class Builder {
        private java.lang.Object _endpointConfigName;
        @javax.annotation.Nullable
        private java.lang.Object _endpointName;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of EndpointConfigName
         * @param value ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @return {@code this}
         */
        public Builder withEndpointConfigName(final java.lang.String value) {
            this._endpointConfigName = java.util.Objects.requireNonNull(value, "endpointConfigName is required");
            return this;
        }
        /**
         * Sets the value of EndpointConfigName
         * @param value ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @return {@code this}
         */
        public Builder withEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value) {
            this._endpointConfigName = java.util.Objects.requireNonNull(value, "endpointConfigName is required");
            return this;
        }
        /**
         * Sets the value of EndpointName
         * @param value ``AWS::SageMaker::Endpoint.EndpointName``
         * @return {@code this}
         */
        public Builder withEndpointName(@javax.annotation.Nullable final java.lang.String value) {
            this._endpointName = value;
            return this;
        }
        /**
         * Sets the value of EndpointName
         * @param value ``AWS::SageMaker::Endpoint.EndpointName``
         * @return {@code this}
         */
        public Builder withEndpointName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._endpointName = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::SageMaker::Endpoint.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::SageMaker::Endpoint.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EndpointResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public EndpointResourceProps build() {
            return new EndpointResourceProps() {
                private java.lang.Object $endpointConfigName = java.util.Objects.requireNonNull(_endpointConfigName, "endpointConfigName is required");
                @javax.annotation.Nullable
                private java.lang.Object $endpointName = _endpointName;
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getEndpointConfigName() {
                    return this.$endpointConfigName;
                }

                @Override
                public void setEndpointConfigName(final java.lang.String value) {
                    this.$endpointConfigName = java.util.Objects.requireNonNull(value, "endpointConfigName is required");
                }

                @Override
                public void setEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$endpointConfigName = java.util.Objects.requireNonNull(value, "endpointConfigName is required");
                }

                @Override
                public java.lang.Object getEndpointName() {
                    return this.$endpointName;
                }

                @Override
                public void setEndpointName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$endpointName = value;
                }

                @Override
                public void setEndpointName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$endpointName = value;
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which for javascript object literal which adhere to this interface.
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sagemaker.cloudformation.EndpointResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
         */
        @Override
        public java.lang.Object getEndpointConfigName() {
            return this.jsiiGet("endpointConfigName", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
         */
        @Override
        public void setEndpointConfigName(final java.lang.String value) {
            this.jsiiSet("endpointConfigName", java.util.Objects.requireNonNull(value, "endpointConfigName is required"));
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
         */
        @Override
        public void setEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("endpointConfigName", java.util.Objects.requireNonNull(value, "endpointConfigName is required"));
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getEndpointName() {
            return this.jsiiGet("endpointName", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
         */
        @Override
        public void setEndpointName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("endpointName", value);
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
         */
        @Override
        public void setEndpointName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("endpointName", value);
        }

        /**
         * ``AWS::SageMaker::Endpoint.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::Endpoint.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::SageMaker::Endpoint.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}

==> sagemaker-0.9.1-sources.jar: software/amazon/awscdk/services/sagemaker/cloudformation/EndpointResourceProps.java <==
package software.amazon.awscdk.services.sagemaker.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:15:29.322Z")
public interface EndpointResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::SageMaker::Endpoint.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
     */
    java.lang.Object getEndpointConfigName();
    /**
     * ``AWS::SageMaker::Endpoint.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
     */
    void setEndpointConfigName(final java.lang.String value);
    /**
     * ``AWS::SageMaker::Endpoint.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
     */
    void setEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::Endpoint.EndpointName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
     */
    java.lang.Object getEndpointName();
    /**
     * ``AWS::SageMaker::Endpoint.EndpointName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
     */
    void setEndpointName(final java.lang.String value);
    /**
     * ``AWS::SageMaker::Endpoint.EndpointName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
     */
    void setEndpointName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::Endpoint.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::SageMaker::Endpoint.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
     */
    void setTags(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::Endpoint.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link EndpointResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link EndpointResourceProps}
     */
    final class Builder {
        private java.lang.Object _endpointConfigName;
        @javax.annotation.Nullable
        private java.lang.Object _endpointName;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of EndpointConfigName
         * @param value ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @return {@code this}
         */
        public Builder withEndpointConfigName(final java.lang.String value) {
            this._endpointConfigName = java.util.Objects.requireNonNull(value, "endpointConfigName is required");
            return this;
        }
        /**
         * Sets the value of EndpointConfigName
         * @param value ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @return {@code this}
         */
        public Builder withEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value) {
            this._endpointConfigName = java.util.Objects.requireNonNull(value, "endpointConfigName is required");
            return this;
        }
        /**
         * Sets the value of EndpointName
         * @param value ``AWS::SageMaker::Endpoint.EndpointName``
         * @return {@code this}
         */
        public Builder withEndpointName(@javax.annotation.Nullable final java.lang.String value) {
            this._endpointName = value;
            return this;
        }
        /**
         * Sets the value of EndpointName
         * @param value ``AWS::SageMaker::Endpoint.EndpointName``
         * @return {@code this}
         */
        public Builder withEndpointName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._endpointName = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::SageMaker::Endpoint.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::SageMaker::Endpoint.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EndpointResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public EndpointResourceProps build() {
            return new EndpointResourceProps() {
                private java.lang.Object $endpointConfigName = java.util.Objects.requireNonNull(_endpointConfigName, "endpointConfigName is required");
                @javax.annotation.Nullable
                private java.lang.Object $endpointName = _endpointName;
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getEndpointConfigName() {
                    return this.$endpointConfigName;
                }

                @Override
                public void setEndpointConfigName(final java.lang.String value) {
                    this.$endpointConfigName = java.util.Objects.requireNonNull(value, "endpointConfigName is required");
                }

                @Override
                public void setEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$endpointConfigName = java.util.Objects.requireNonNull(value, "endpointConfigName is required");
                }

                @Override
                public java.lang.Object getEndpointName() {
                    return this.$endpointName;
                }

                @Override
                public void setEndpointName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$endpointName = value;
                }

                @Override
                public void setEndpointName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$endpointName = value;
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sagemaker.cloudformation.EndpointResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
         */
        @Override
        public java.lang.Object getEndpointConfigName() {
            return this.jsiiGet("endpointConfigName", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
         */
        @Override
        public void setEndpointConfigName(final java.lang.String value) {
            this.jsiiSet("endpointConfigName", java.util.Objects.requireNonNull(value, "endpointConfigName is required"));
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointconfigname
         */
        @Override
        public void setEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("endpointConfigName", java.util.Objects.requireNonNull(value, "endpointConfigName is required"));
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getEndpointName() {
            return this.jsiiGet("endpointName", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
         */
        @Override
        public void setEndpointName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("endpointName", value);
        }

        /**
         * ``AWS::SageMaker::Endpoint.EndpointName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-endpointname
         */
        @Override
        public void setEndpointName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("endpointName", value);
        }

        /**
         * ``AWS::SageMaker::Endpoint.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::Endpoint.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::SageMaker::Endpoint.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpoint.html#cfn-sagemaker-endpoint-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}
